package tracing

import (
	"crypto/x509"
	"errors"
	"fmt"
	"os"

	"git.frostfs.info/TrueCloudLab/frostfs-node/cmd/frostfs-node/config"
	"git.frostfs.info/TrueCloudLab/frostfs-node/misc"
	"git.frostfs.info/TrueCloudLab/frostfs-observability/tracing"
)

const (
	subsection = "tracing"
)

// ToTracingConfig extracts tracing config.
func ToTracingConfig(c *config.Config) (*tracing.Config, error) {
	conf := &tracing.Config{
		Enabled:    config.BoolSafe(c.Sub(subsection), "enabled"),
		Exporter:   tracing.Exporter(config.StringSafe(c.Sub(subsection), "exporter")),
		Endpoint:   config.StringSafe(c.Sub(subsection), "endpoint"),
		Service:    "frostfs-node",
		InstanceID: getInstanceIDOrDefault(c),
		Version:    misc.Version,
	}

	if trustedCa := config.StringSafe(c.Sub(subsection), "trusted_ca"); trustedCa != "" {
		caBytes, err := os.ReadFile(trustedCa)
		if err != nil {
			return nil, fmt.Errorf("cannot read trusted ca cert by path: %w", err)
		}
		certPool := x509.NewCertPool()
		ok := certPool.AppendCertsFromPEM(caBytes)
		if !ok {
			return nil, errors.New("can't fill cert pool by ca cert")
		}
		conf.ServerCaCertPool = certPool
	}
	return conf, nil
}

func getInstanceIDOrDefault(c *config.Config) string {
	s := config.StringSlice(c.Sub("node"), "addresses")
	if len(s) > 0 {
		return s[0]
	}
	return ""
}
